@@ -22,7 +22,6 @@
 #include <Lum/Base/String.h>
 
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 #include <Lum/TextValue.h>
 
 #include "FunctionInput.h"
@@ -30,16 +29,11 @@
 
 Calc::Calc()
 : calculate(new Lum::Model::Action()),
-  history(new Lum::Model::ListTable(1)),
+  history(new Lum::Model::StringTable()),
   calcInput(new Lum::Model::String(L"")),
   calcResult(new Lum::Model::String(L""))
 {
-  AttachModel(calculate);
-}
-
-Calc::~Calc()
-{
-  UnattachModel(calculate);
+  Observe(calculate);
 }
 
 void Calc::Calculate()
@@ -52,12 +46,8 @@ void Calc::Calculate()
   expression=parser.Parse(Lum::Base::WStringToString(calcInput->Get()),result,pos);
 
   if (result==Parser::OK) {
-    Lum::Model::ListTable::StdEntry *entry;
-
-    if (history->GetRows()==0 || history->GetString(1,1)!=calcInput->Get()) {
-      entry=new Lum::Model::ListTable::StdEntry(history);
-      entry->SetString(1,calcInput->Get());
-      history->Prepend(entry);
+    if (history->GetRows()==0 || history->GetEntry(1)!=calcInput->Get()) {
+      history->Prepend(calcInput->Get());
     }
 
     expression->Calculate(value,result);
@@ -90,18 +80,16 @@ void Calc::CalcSize()
   Lum::TextValue *value;
 
   panel=new Lum::VPanel();
-  panel->SetFlex(true,true);
 
   comboInput=new Lum::TextEditCombo();
   comboInput->SetFlex(true,false);
-  comboInput->SetWidth(Lum::Base::Size::stdCharWidth,30);
   comboInput->SetModel(calcInput);
   comboInput->SetTableModel(history);
   comboInput->GetString()->SetReturnAction(calculate);
   comboInput->GetString()->SetRequestsKeyboard(false);
   panel->Add(comboInput);
 
-  panel->Add(new Lum::VSpace());
+  panel->AddSpace();
 
   value=new Lum::TextValue();
   value->SetFlex(true,false);
@@ -109,7 +97,7 @@ void Calc::CalcSize()
   value->SetModel(calcResult);
   panel->Add(value);
 
-  panel->Add(new Lum::VSpace());
+  panel->AddSpace();
 
   input=new FunctionInput();
   input->SetFlex(true,true);
@@ -119,14 +107,6 @@ void Calc::CalcSize()
 
   container=panel;
 
-  container->SetParent(this);
-  container->CalcSize();
-
-  minWidth=container->GetOMinWidth();
-  minHeight=container->GetOMinHeight();
-  width=container->GetOWidth();
-  height=container->GetOHeight();
-
   Component::CalcSize();
 }
 
