@@ -46,16 +46,16 @@ public:
 
   // Error codes
   enum ReturnCode {
-    OK,
-    NODIGIT,
-    NORBRAC,
-    WRONGBRAC,
-    UNKNOWNIDENT,
-    ILLGVAL,
-    UNKNOWN,
-    NOOP,
-    DIVBYZERO,
-    NEGVAL
+    OK           = 0,
+    NODIGIT      = 1,
+    NORBRAC      = 2,
+    WRONGBRAC    = 3,
+    UNKNOWNIDENT = 4,
+    ILLGVAL      = 5,
+    UNKNOWN      = 6,
+    NOOP         = 7,
+    DIVBYZERO    = 8,
+    NEGVAL       = 9
   };
 
 public:
