@@ -150,12 +150,13 @@ void UnitConversion::Convert()
 
   expression=parser.Parse(Lum::Base::WStringToString(srcAlt->GetFactor()),returnCode,pos,false);
   if (expression==NULL) {
-    result->Set(L"Internal error: src factor has errors");
+    result->Set(L"Internal error: src factor has parse error (code "+Lum::Base::NumberToWString((size_t)returnCode)+L")");
+
     return;
   }
 
   if (!expression->Calculate(srcFactor,returnCode)) {
-    result->Set(L"Internal error: src factor has errors");
+    result->Set(L"Internal error: src factor has calculation error (code "+Lum::Base::NumberToWString((size_t)returnCode)+L")");
     delete expression;
     return;
   }
@@ -164,12 +165,12 @@ void UnitConversion::Convert()
 
   expression=parser.Parse(Lum::Base::WStringToString(destAlt->GetFactor()),returnCode,pos,false);
   if (expression==NULL) {
-    result->Set(L"Internal error: dest factor has errors");
+    result->Set(L"Internal error: dest factor has parse error (code "+Lum::Base::NumberToWString((size_t)returnCode)+L")");
     return;
   }
 
   if (!expression->Calculate(destFactor,returnCode)) {
-    result->Set(L"Internal error: dest factor has errors");
+    result->Set(L"Internal error: dest factor has calculation error (code "+Lum::Base::NumberToWString((size_t)returnCode)+L")");
     delete expression;
     return;
   }
